OC.L10N.register(
    "files",
    {
    "File could not be found" : "Filen kunne ikke findes",
    "Move or copy" : "Flyt eller kopier",
    "Download" : "Download",
    "Delete" : "Slet",
    "Tags" : "Tags",
    "Show list view" : "Vis som liste",
    "Show grid view" : "Vis som gitter",
    "Home" : "Hjem",
    "Close" : "Luk",
    "Could not create folder \"{dir}\"" : "Kunne ikke oprette mappen \"{dir}\"",
    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
    "Upload cancelled." : "Upload afbrudt.",
    "Processing files …" : "Behandler filer...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Target folder \"{dir}\" does not exist any more" : "Destinationsmappen \"{dir}\" findes ikke længere",
    "Not enough free space" : "Ikke nok fri plads",
    "An unknown error has occurred" : "En ukendt fejl er opstået",
    "File could not be uploaded" : "Filen kunne ikke uploades",
    "Uploading …" : "Uploader ...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Uploader … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} af {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Upload af dette er ikke supporteret",
    "Target folder does not exist any more" : "Destinationsmappen findes ikke længere",
    "Operation is blocked by access control" : "Operationen blev blokeret af adgangskontrollen",
    "Error when assembling chunks, status code {status}" : "Fejl ved montering af klumper, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Omdøb",
    "Move" : "Flyt",
    "Copy" : "Kopier",
    "Choose target folder" : "Vælg destinationsmappe",
    "Set reminder" : "Sæt påmindelse",
    "Edit locally" : "Rediger lokalt",
    "Open" : "Åbn",
    "Delete file" : "Slet fil",
    "Delete folder" : "Slet mappe",
    "Disconnect storage" : "Frakobl lager",
    "Leave this share" : "Forlad dette delte drev",
    "Could not load info for file \"{file}\"" : "Kunne ikke indlæse information for filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Please select tag(s) to add to the selection" : "Vælg venligst tag(s) for at tilføje til udvalget",
    "Apply tag(s) to selection" : "Anvend tag(s) på markeringen",
    "Select directory \"{dirName}\"" : "Vælg katalog \"{dirName}\"",
    "Select file \"{fileName}\"" : "Vælg fil \"{fileName}\"",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Could not move \"{file}\", target exists" : "Kunne ikke flytte \"{file}\" - der findes allerede en fil med dette navn",
    "Could not move \"{file}\"" : "Kunne ikke flytte \"{file}\"",
    "copy" : "kopiér",
    "Could not copy \"{file}\", target exists" : "Kunne ikke kopiere \"{file}\" - der findes allerede en fil med dette navn",
    "Could not copy \"{file}\"" : "Kunne ikke kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopirede {origin} ind i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "kopierede {origin} og {nbfiles} andre filer ind i {destination}",
    "Failed to redirect to client" : "Kunne ikke omdirigere til klienten",
    "{newName} already exists" : "{newName} eksisterer allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunne ikke omdøbe \"{fileName}\", den findes ikke længere",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
    "Could not rename \"{fileName}\"" : "Kunne ikke omdøbe \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunne ikke oprette filen \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunne ikke oprette filen \"{file}\", da den allerede findes",
    "Could not create folder \"{dir}\" because it already exists" : "Kunne ikke oprette mappen \"{dir}\", da den allerede findes",
    "Could not fetch file details \"{file}\"" : "Kunne ikke hente filoplysningerne \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Fejl under sletning af filen \"{fileName}\"",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søgeresultater i andre mapper efter {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Indtast mere end to tegn for at søge i andre mapper",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n skujlte inkluderet","%n skujlte inkluderet"],
    "You do not have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "New file/folder menu" : "Ny fil/mappe menu",
    "Select file range" : "Vælg filområde",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} af {quota} brugt",
    "{used} used" : "{used} brugt",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" er ikke tilladt i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tilladt filtype",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagringen af {owner} er fuld, filer kan ikke længere opdateres eller synkroniseres!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppemappen \"{mountPoint}\" er fuld, filer kan ikke længere opdateres eller synkroniseres!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Eksternt lager \"{mountPoint}\" er fyldt, filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Din lagerplads er fuld, filer kan ikke længere opdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Opbevaring af {owner} er næsten fuld ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppemappen \"{mountPoint}\" er næsten fuld ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Eksternt lager \"{mountPoint}\" er næsten fyldt ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Din lagerplads er næsten fuld ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
    "View in folder" : "Vis i mappe",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "New folder" : "Ny mappe",
    "Create new folder" : "Opret ny mappe",
    "Upload file" : "Upload fil",
    "Recent" : "Seneste",
    "Not favorited" : "Ingen foretrukne",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Tilføj til favoritter",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "Added to favorites" : "Tilføjet til favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du har tilføjet {file} til dine favoritter",
    "You removed {file} from your favorites" : "Du har fjernet {file} fra dine favoritter",
    "Favorites" : "Foretrukne",
    "File changes" : "Fil ændringer",
    "Created by {user}" : "Oprettet af {user}",
    "Changed by {user}" : "Ændret af {user}",
    "Deleted by {user}" : "Slettet af {user}",
    "Restored by {user}" : "Gendannet af {user}",
    "Renamed by {user}" : "Omdøbt af {user}",
    "Moved by {user}" : "Flyttet af {user}",
    "You created {file}" : "Du har oprettet {file}",
    "You created an encrypted file in {file}" : "Du har oprettet en krypteret fil i {file}",
    "{user} created {file}" : "{user} oprettede {file}",
    "{user} created an encrypted file in {file}" : "{user} har oprettet en krypteret fil i {file}",
    "{file} was created in a public folder" : "{file} blev oprettet i en offentlig mappe",
    "You changed {file}" : "Du ændrede {file}",
    "You changed an encrypted file in {file}" : "Du har ændret en krypteret fil i {file}",
    "{user} changed {file}" : "{user} ændrede {file}",
    "{user} changed an encrypted file in {file}" : "{user} har ændret en krypteret fil i {file}",
    "You deleted {file}" : "Du slettede {file}",
    "You deleted an encrypted file in {file}" : "Du har slettet en krypteret fil i {file}",
    "{user} deleted {file}" : "{user} slettede {file}",
    "{user} deleted an encrypted file in {file}" : "{user} har slettet en krypteret fil i {file}",
    "You restored {file}" : "Du gendannede {file}",
    "{user} restored {file}" : "{user} gendannede {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du omdøbte {oldfile} (skjult) til {newfile} (skjult)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du omdøbte {oldfile} (skjult) til {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du omdøbte {oldfile} til {newfile} (skjult)",
    "You renamed {oldfile} to {newfile}" : "Du omdøbte {oldfile} til {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} omdøbte {oldfile} (skjult) til {newfile} (skjult)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} omdøbte {oldfile} (skjult) til {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} omdøbte {oldfile} til {newfile} (skjult)",
    "{user} renamed {oldfile} to {newfile}" : "{user} omdøbte {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttede {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttede {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil er blevet tilføjet eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "En favoritfil eller -mappe er blevet <strong>ændret</strong>",
    "Upload (max. %s)" : "Upload (max. %s)",
    "Accept" : "Accepter",
    "Reject" : "Afvis",
    "Incoming ownership transfer from {user}" : "Indgående ejerskabsoverførsel fra {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vil du acceptere {path}?\n\nBemærk: Overførselsprocessen efter accept kan tage op til 1 time.",
    "Ownership transfer failed" : "Overførsel af ejerskab mislykkedes",
    "Your ownership transfer of {path} to {user} failed." : "Din ejerskabsoverførsel af {path} til {user} mislykkedes.",
    "The ownership transfer of {path} from {user} failed." : "Ejerskabsoverførslen af {path} fra {user} mislykkedes.",
    "Ownership transfer done" : "Ejerskabsoverdragelse gennemført",
    "Your ownership transfer of {path} to {user} has completed." : "Din ejerskabsoverførsel af {path} til {user} er fuldført.",
    "The ownership transfer of {path} from {user} has completed." : "Ejerskabsoverførslen af {path} fra {user} er fuldført.",
    "in %s" : "i %s",
    "File Management" : "Filhåndtering",
    "Reload current directory" : "Genindlæs den aktuelle mappe",
    "Go to the \"{dir}\" directory" : "Gå til mappen \"{dir}\"",
    "Drag and drop files here to upload" : "Træk filer hertil for at uploade",
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
    "\"{displayName}\" action failed" : "\"{displayName}\"-handling mislykkedes",
    "Rename file" : "Omdøb fil",
    "File name" : "Filnavn",
    "Folder name" : "Mappenavn",
    "This node is unavailable" : "Denne node er ikke tilgængelig ",
    "Download file {name}" : "Download fil {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" er ikke en tilladt filtype.",
    "{newName} already exists." : "{newName} findes allerede.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" er ikke tilladt i filnavnet",
    "Name cannot be empty" : "Navn må ikke være tomt",
    "Another entry with the same name already exists" : "Dette navn er allerede i brug",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Omdøbte \"{oldName}\" til \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kunne ikke omdøbe \"{oldName}\", da den findes ikke længere",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{newName}\" bruges allerede i mappen \"{dir}\". Vælg et andet navn.",
    "Could not rename \"{oldName}\"" : "Kunne ikke omdøbe \"{oldName}\"",
    "Total rows summary" : "Samlet række antal",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" fejlede i nogle aspekter.",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\"-handling blev udført korrekt",
    "List of files and folders." : "Liste med filer og mapper.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
    "File not found" : "Filen blev ikke fundet",
    "Storage informations" : "Lagerinformationer",
    "{usedQuotaByte} used" : "{usedQuotaByte} brugt",
    "{relative}% used" : "{relative}% brugt",
    "Could not refresh storage stats" : "Kunne ikke opdatere lageroplysninger",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Create" : "Opret",
    "Transfer ownership of a file or folder" : "Overfør ejerskab af en fil eller mappe",
    "Choose file or folder to transfer" : "Vælg fil eller mappe til overførsel",
    "Change" : "Ændr",
    "New owner" : "Ny ejer",
    "Choose a file or folder to transfer" : "Vælg en fil eller mappe til overførsel",
    "Transfer" : "Overfør",
    "Transfer {path} to {userid}" : "Overfør {path} til {userid}",
    "Invalid path selected" : "Ugyldig filsti valgt",
    "Unknown error" : "Ukendt fejl",
    "Ownership transfer request sent" : "Anmodning om ejerskabsoverdragelse sendt",
    "Cannot transfer ownership of a file or folder you do not own" : "Kan ikke overføre ejerskab af en fil eller mappe, du ikke ejer",
    "Select file or folder to link to" : "Vælg fil eller mappe at linke til",
    "Choose {file}" : "Vælg {file}",
    "Loading current folder" : "Indlæser aktuelle mappe",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "Go to the previous folder" : "Gå til forrige mappe",
    "Go back" : "Gå tilbage",
    "Share" : "Del",
    "Shared by link" : "Delt via link",
    "Shared" : "Delt",
    "Switch to list view" : "Skift til listevisning",
    "Switch to grid view" : "Skift til gittervisning",
    "Open the files app settings" : "Åbn fil-app indstillinger",
    "Files settings" : "indstillinger for filer",
    "File cannot be accessed" : "Filen kan ikke tilgås",
    "Open in files" : "Åben i Filer",
    "Sort favorites first" : "Vis favoritter først",
    "Show hidden files" : "Vis skjulte filer",
    "Crop image previews" : "Beskær forhåndsvisninger af billeder",
    "Enable the grid view" : "Aktivér gittervisning",
    "Additional settings" : "Yderligere indstillinger",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopier til udklipsholder",
    "Use this address to access your Files via WebDAV" : "Brug denne adresse til at få adgang til dine filer via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Hvis du har aktiveret 2-faktor godkendelse, skal du oprette en app-token, ved at følge dette link.",
    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
    "WebDAV URL copied to clipboard" : "WebDAV URL kopieret til udklipsholder",
    "Unable to change the favourite state of the file" : "Kan ikke ændre favorittilstanden for filen",
    "Error while loading the file data" : "Fejl under indlæsning af fildata",
    "Pick a template for {name}" : "Vælg en skabelon til {name}",
    "Create a new file with the selected template" : "Opret en ny fil med den valgte skabelon",
    "Creating file" : "Opretter fil",
    "Blank" : "Tom",
    "Unable to create new file from template" : "Kan ikke oprette ny fil fra skabelonen",
    "Delete permanently" : "Slet permanent",
    "Cancel" : "annuller",
    "Destination is not a folder" : "Destinationen er ikke en mappe",
    "This file/folder is already in that directory" : "Filen/mappen er allerede i denne mappe",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan ikke flytte en fil/mappe ind i sig selv, eller til en mappe inden i sig selv",
    "A file or folder with that name already exists in this folder" : "En fil eller mappe med det navn findes allerede i denne mappe",
    "The file does not exist anymore" : "Filen findes ikke længere",
    "Copy to {target}" : "Kopiér til {target}",
    "Move to {target}" : "Flyt til {target}",
    "Cancelled move or copy operation" : "Flytning eller kopiering er annulleret",
    "Open folder {displayName}" : "Åben mappe {displayName}",
    "Open in Files" : "Åben i Filer",
    "Open details" : "Mere information",
    "Created new folder \"{name}\"" : "Oprettede ny mappe \"{name}\"",
    "Filename" : "Filnavn",
    "Unable to initialize the templates directory" : "Kan ikke initialisere skabelonmappen",
    "Create new templates folder" : "Opsæt ny skabelonmappe",
    "Templates" : "Skabeloner",
    "Some files could not be moved" : "Nogle filer kunne ikke flyttes",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappe","{folderCount} mapper"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil og {folderCount} mapper","1 fil og {folderCount} mapper"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil og 1 mapper","{fileCount} filer og 1 mapper"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} filer og {folderCount} mapper",
    "List of favorites files and folders." : "Liste med foretrukne filer og mapper.",
    "No favorites yet" : "Ingen foretrukne endnu",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "All files" : "Alle filer",
    "List of your files and folders." : "Liste med dine filer og mapper.",
    "List of recently modified files and folders." : "Liste med nyligt ændrede filer og mapper.",
    "No recently modified files" : "Ingen filer er ændret for nyligt",
    "Files and folders you recently modified will show up here." : "Filer og mapper som du har ændret for nyligt, vil blive vist her.",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst fil.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Linket er kopieret (dette link kan kun anvendes af brugere med adgang til denne fil/mappe)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte link (virker kun for brugere der har adgang til denne fil/mappe)",
    "You can only favorite a single file or folder at a time" : "Du kan kun favorisere en enkelt fil eller mappe ad gangen",
    "This file has the tag {tag}" : "Denne fil har tagget {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Denne fil har taggene {firstTags} og {lastTag}",
    "\"remote user\"" : "\"ekstern bruger\"",
    "Select the row for {displayName}" : "Vælg rækken for {displayName}",
    "Open folder {name}" : "Åben mappe {name}",
    "Unselect all" : "Fravælg alle",
    "ascending" : "stigende",
    "descending" : "faldende",
    "Sort list by {column} ({direction})" : "Sortér liste efter {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Hele listen er ikke hentet, af hensyn til størrelsen. Listen vil blive hentet løbende som du kører igennem listen.",
    "Search for an account" : "Søg efter en konto",
    "Choose" : "Vælg",
    "No files or folders have been deleted yet" : "Ingen filer eller mappe er slettet endnu",
    "You might not have have permissions to view it, ask the sender to share it" : "Du har muligvis ikke tilladelser til at se.... Bed afsenderen om at dele...",
    "Set up templates folder" : "Opsæt skabelonmappen",
    "Toggle %1$s sublist" : "Skift %1$s underliste",
    "Toggle grid view" : "Vis som gitter",
    "Shares" : "Delinger",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med dig",
    "Deleted shares" : "Slettede delinger",
    "Pending shares" : "Afventende delinger",
    "The files is locked" : "Filerne er låste"
},
"nplurals=2; plural=(n != 1);");
